@@ -113,6 +113,7 @@ class Witter():
         self.osso_rpc = osso.Rpc(self.osso_c)
         self.osso_rpc.set_rpc_callback("uk.wouldd.witter", "/uk/wouldd/witter", "uk.wouldd.witter", self.cb_switch_view, self.osso_c)
         # set name of application: this shows in titlebar
+        
         system_bus = dbus.Bus.get_system()
         system_bus.add_signal_receiver(self._on_orientation_signal, \
                  signal_name='sig_device_orientation_ind', \
@@ -166,6 +167,7 @@ class Witter():
         self.ui = ui.WitterUI(self)
         self.ui.setActiveListStore(self.activeAccount.getTimeline(),4)
         self.ui.theme = self.theme
+        self.ui.load_theme_icons()
         self.ui.select_ui_theme(self.theme)
         self.gettingTweets = False
         if (self.activeAccount.getUsername() != "Username"):
@@ -173,7 +175,8 @@ class Witter():
         #
         #need to load all account references, and set the active account
         #
-
+        from portrait import FremantleRotation
+        FremantleRotation("Witter", self.ui.window)
 
 
     def quit(self, *args):
@@ -966,10 +969,34 @@ class Witter():
          if (orientation == 'portrait'):
             print "switched to portrait"
             self.ui.cell.set_property('wrap-width', 400)
+            self.ui.icon_size = 30
+            self.ui.load_theme_icons()
+            self.ui.define_ui_buttons()
+            
          if (orientation == 'landscape'):
             print "switched to landscape"
             self.ui.cell.set_property('wrap-width', 730)
-
+            self.ui.icon_size = 48
+            self.ui.load_theme_icons()
+            self.ui.define_ui_buttons()
+         curView = self.ui.getCurrentView()  
+         if (curView == self.ui.TIMELINE_VIEW):
+            self.ui.switch_view_to("timeline")
+         elif (curView == self.ui.DM_VIEW):
+            self.ui.switch_view_to("direct")
+         elif (curView == self.ui.MENTIONS_VIEW):
+            self.ui.switch_view_to("mentions")
+         elif (curView == self.ui.PUBLIC_VIEW):
+            self.ui.switch_view_to("public")
+         elif (curView == self.ui.TRENDS_VIEW):
+            self.ui.switch_view_to("trends")
+         elif (curView == self.ui.FRIENDS_VIEW):
+            self.ui.switch_view_to("friends")
+         elif (curView == self.ui.SEARCH_VIEW):
+            self.ui.switch_view_to("search")
+         elif (curView == self.ui.USERHIST_VIEW):
+            self.ui.switch_view_to("user")
+            
     def getVersion(self):
         return self.version
 
